/***************************************************************************
*   KBlocks, a falling blocks game by KDE                                 *
*   Copyright (C) 2019 Thomas Branch <kde@twig.hk>                        *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/
#ifndef UTILS_H
#define UTILS_H

#include "KBlocksDefine.h"

namespace Utils {
	timeLong getMillisecOfNow();
}
#endif
